package org.kohsuke.gzipxml;

import java.io.IOException;
import java.io.OutputStream;
import java.util.zip.GZIPOutputStream;

/**
 * Replacement of {@link java.util.zip.GZIPOutputStream} with
 * additional functionality to specify the compression level.
 * 
 * <p>
 * THIS SOFTWARE IS IN PUBLIC DOMAIN. NO WARRANTY.
 * 
 * <p>
 * Although {@link StreamResult} supports the use of {@link Writer},
 * this implementation doesn't, since the gzip compression works on
 * the stream level.
 * <p>
 * This class also doesn't support the <code>setXXX</code> methods.
 * Calling those methods throw an {@link java.lang.UnsupportedOperationException}.
 * 
 * @author Kohsuke Kawaguchi (kk@kohsuke.org)
 */
public class GZipOutputStream extends GZIPOutputStream {
    /**
     * Creates a new output stream with a default buffer size.
     * @param out the output stream
     * @exception IOException If an I/O error has occurred.
     */
    public GZipOutputStream(OutputStream out) throws IOException {
        super(out);
    }

    /**
     * Creates a new output stream with the specified buffer size.
     * @param out the output stream
     * @param size the output buffer size
     * @exception IOException If an I/O error has occurred.
     * @exception IllegalArgumentException if size is <= 0
     */
    public GZipOutputStream(OutputStream out, int size) throws IOException {
        super(out, size);
    }

    /**
     * Creates a new output stream with the specified buffer size.
     * @param out the output stream
     * @param size the output buffer size
     * @param compressionLevel
     *      the compression level (0-9).
     *      0 for the fastest compression, 9 for the smallest result.
     * @exception IOException If an I/O error has occurred.
     * @exception IllegalArgumentException if size is <= 0
     */
    public GZipOutputStream(OutputStream out, int size, int compressionLevel) throws IOException {
        super(out, size);
        super.def.setLevel(compressionLevel);
    }

}
