package org.kohsuke.gzipxml;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.Writer;

import javax.xml.transform.stream.StreamResult;

/**
 * {@link StreamSource} that produces from gzip-compressed XML stream.
 * <p>
 * THIS SOFTWARE IS IN PUBLIC DOMAIN. NO WARRANTY.
 * 
 * <p>
 * Although {@link StreamResult} supports the use of {@link Writer},
 * this implementation doesn't, since the gzip compression works on
 * the stream level.
 * <p>
 * This class also doesn't support the <code>setXXX</code> methods.
 * Calling those methods throw an {@link java.lang.UnsupportedOperationException}.
 * 
 * @author Kohsuke Kawaguchi (kk@kohsuke.org)
 */
public class GZipStreamResult extends StreamResult {
    public GZipStreamResult(File f) throws IOException {
        this(new FileOutputStream(f));
    }

    public GZipStreamResult(File f,int compressionLevel) throws IOException {
        this(new FileOutputStream(f),compressionLevel);
    }

    public GZipStreamResult(OutputStream outputStream) throws IOException {
        this(outputStream,1);
    }

    public GZipStreamResult(OutputStream outputStream, int compressionLevel) throws IOException {
        super(new GZipOutputStream(outputStream,512,compressionLevel));
    }


    public void setOutputStream(OutputStream outputStream) {
        throw new UnsupportedOperationException();
    }

    public void setSystemId(File f) {
        throw new UnsupportedOperationException();
    }

    public void setSystemId(String systemId) {
        throw new UnsupportedOperationException();
    }

    public void setWriter(Writer writer) {
        throw new UnsupportedOperationException();
    }
}
