package org.kohsuke.gzipxml;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.zip.GZIPInputStream;

import javax.xml.transform.stream.StreamSource;

/**
 * {@link StreamSource} that reads from gzip-compressed XML stream.
 * <p>
 * THIS SOFTWARE IS IN PUBLIC DOMAIN. NO WARRANTY.
 * 
 * @author Kohsuke Kawaguchi (kk@kohsuke.org)
 */
public class GZipStreamSource extends StreamSource {
    
    /**
     * Creates a {@link StreamSource} from a gzip-compressed XML file.
     */
    public GZipStreamSource( File file ) throws IOException {
        this( new FileInputStream(file), file.toURL().toExternalForm() );
    }
    
    /**
     * Creates a {@link StreamSource} from a gzip-compressed stream.
     */
    public GZipStreamSource( InputStream stream ) throws IOException {
        super( new GZIPInputStream(stream) );
    }
    
    /**
     * Creates a {@link StreamSource} from a gzip-compressed stream.
     *
     * <p>This constructor allows the systemID to be set in addition
     * to the input stream, which allows relative URIs
     * to be processed.</p>
     */
    public GZipStreamSource( InputStream stream, String systemId ) throws IOException {
        super( new GZIPInputStream(stream), systemId );
    }
    
    /**
     * Creates a {@link StreamSource} from a gzip-compressed stream.
     * @param systemId
     */
    public GZipStreamSource( String url ) throws IOException {
        this( new URL(url).openStream(), url );
    }
}
